@@ -1,7 +1,7 @@
 is.category <- function(x) inherits(x, "Category")
 
 setValidity("Category", function(object) {
-    is.cat <- all(c("id", "name") %in% names(object))
+    is.cat <- all(c("name") %in% names(object))
     if (!all(is.cat)) {
         val <- "Not a category"
     } else {
@@ -42,6 +42,27 @@ setMethod("value", "Category", function(x) {
 #' @export
 setMethod("value<-", "Category", setValue)
 
+setDate <- function(x, value) {
+    # Relies on server validation for acceptable formats
+    # Consider adding strftime/strptime support if users
+    # are used to working with dates (most are probably not)
+    value_to_set <- suppressWarnings(as.character(value))
+    x[["date"]] <- value_to_set
+    return(x)
+}
+
+#' @rdname describe-entity
+#' @export
+setMethod("dates", "Category", function(x) {
+    v <- as.character(x[["date"]])
+    return(ifelse(is.null(v), NA_character_, v))
+})
+
+#' @rdname describe-entity
+#' @export
+setMethod("dates<-", "Category", setDate)
+
+
 #' @rdname is-na-categories
 #' @export
 setMethod("is.na", "Category", function(x) isTRUE(x$missing))
