@@ -25,7 +25,7 @@
 #'     names()
 #' # The assignment method lets you move a dataset to a project
 #' proj <- cd(projects(), "Important Clients")
-#' ds <- loadDataset("New important client survey")
+#' ds <- loadDataset("New important client survey", project = "Studies")
 #' datasets(proj) <- ds
 #' }
 datasets <- function(x = getAPIRoot()) {
@@ -49,10 +49,6 @@ datasets <- function(x = getAPIRoot()) {
 #' are in a project. It is equivalent to `names(datasets(proj))`, with some
 #' additional optional arguments.
 #'
-#' Specifying `listDatasets(shiny = TRUE)` will, instead of printing dataset
-#' names, load a Shiny gadget that provides a GUI for navigating the project
-#' tree to find a dataset, if you're running in RStudio.
-#'
 #' @param kind character specifying whether to look in active, archived, or all
 #' datasets. Default is "active", i.e. non-archived.
 #' @param project `ProjectFolder` entity, character name of a project, or
@@ -61,9 +57,7 @@ datasets <- function(x = getAPIRoot()) {
 #' your personal folder will be used.
 #' @param refresh logical: should the function check the Crunch API for new
 #' datasets? Default is FALSE.
-#' @param shiny logical: launch a Shiny gadget to help select the right dataset.
-#' The gadget will return a valid `loadDataset()` call which loads the selected
-#' dataset. The gadget requires RStudio, as well as the `crunchy` package.
+#' @param shiny deprecated, no longer works
 #' @return A character vector of dataset names, each of which would be a valid
 #' input for [loadDataset()]
 #' @export
@@ -72,7 +66,7 @@ listDatasets <- function(kind = c("active", "all", "archived"),
                          refresh = FALSE,
                          shiny = FALSE) {
     if (shiny) {
-        listDatasetGadget(kind, refresh)
+        halt("listDatsets(shiny = TRUE) is no longer supported")
     } else {
         Call <- match.call()
         if (refresh) {
@@ -116,34 +110,32 @@ listDatasets <- function(kind = c("active", "all", "archived"),
 #' and analysis as if the dataset were fully resident on your computer, without
 #' having to pull data locally.
 #'
-#' You can specify a dataset to load by its human-friendly "name", possibly also
-#' by indicating a project (folder) to find it in. This makes code more
+#' You can specify a dataset to load by its human-friendly "name", within
+#' the project (folder) to find it in. This makes code more
 #' readable, but it does mean that if the dataset is renamed or moved to a
 #' different folder, your code may no longer work. The fastest, most reliable
 #' way to use `loadDataset()` is to provide a URL to the dataset--the dataset's
 #' URL will never change.
 #'
-#' @param dataset character, the name or path to a Crunch dataset to load, or a
+#' @param dataset character, the path to a Crunch dataset to load, or a
 #' dataset URL. If `dataset` is a path to a dataset in a project, the path will
-#' be be parsed and walked, relative to `project` if specified, and the
-#' function will look for the dataset inside that project. If no path is
-#' specified and no `project` provided, the function will call a search API to
-#' do an exact string match on dataset names.
+#' be be parsed and walked, relative to `project`, and the  function will look
+#' for the dataset inside that project. If `dataset` is just a string and `project`
+#' is set to `NULL`, the function will assume that `dataset` is the dataset id.
 #' @param kind character specifying whether to look in active, archived, or all
 #' datasets. Default is "active", i.e. non-archived.
-#' @param project `ProjectFolder` entity, character name (path) to a project, or
-#' `NULL`, the default. If a Project entity or reference is supplied, either
-#' here or as a path in `dataset`, the dataset lookup will be limited to that
-#' project only.
+#' @param project `ProjectFolder` entity, character name (path) to a project.
+#' Defaults to the project set in `envOrOption('crunch.default.project')`
+#' or "./" (the project root), if the default is not set.
 #' @param refresh logical: should the function check the Crunch API for new
 #' datasets? Default is `FALSE`.
 #' @return An object of class `CrunchDataset`.
 #'
 #' @examples
 #' \dontrun{
-#' ds <- loadDatasets("A special dataset")
-#' ds2 <- loadDatasets("~/My dataset")
-#' ds3 <- loadDataset("My dataset", project = "~") # Same as ds2
+#' ds <- loadDatasets("A special dataset", project = "Studies")
+#' ds2 <- loadDatasets("~/My dataset", project = "Studies")
+#' ds3 <- loadDataset("My dataset", project = projects()[["Studies"]]) # Same as ds2
 #' ds4 <- loadDataset("https://app.crunch.io/api/datasets/bd3ad2/")
 #' }
 #' @export
@@ -151,7 +143,7 @@ listDatasets <- function(kind = c("active", "all", "archived"),
 #' paths.
 loadDataset <- function(dataset,
                         kind = c("active", "all", "archived"),
-                        project = NULL,
+                        project = defaultCrunchProject("."),
                         refresh = FALSE) {
     if (inherits(dataset, "DatasetTuple")) {
         return(entity(dataset))
@@ -174,6 +166,12 @@ loadDataset <- function(dataset,
             archived = archived(found)
         )
         if (length(found) == 0) {
+            if (missing(project)) {
+                warn_once(
+                    "Finding datasets by name without specifying a path is no longer supported.",
+                    option = "find.dataset.no.project"
+                )
+            }
             halt(dQuote(dataset), " not found")
         }
         ## This odd selecting behavior handles the multiple matches case
@@ -239,27 +237,36 @@ lookupDataset <- function(x, project = NULL) {
     # `project`
     dspath <- parseFolderPath(x)
     x <- tail(dspath, 1)
+
     if (length(dspath) == 1 && is.null(project)) {
-        # If don't have a project, query by name
-        return(findDatasetsByName(x))
+        # This code path used to use the datasets by_name endpoint. However
+        # As of 2024-11, that endpoint is no longer very useful because it only
+        # surfaces datasets that are in personal folders (going away very soon) &
+        # direct dataset shares (deprecated).
+        # So we use this to load by dataset id, a nice convenience feature.
+        # To get here, a user had to explicitly set `project=NULL` so they're
+        # presumably not here accidentally
+        pseudo_shoji <- tryCatch({
+            ds_base_url <- absoluteURL("datasets/", envOrOption("crunch.api"))
+            ds_entity <- crGET(paste0(ds_base_url, "/", x))
+            # Need to make this pseudo DatasetCatalog to match old API call (because `loadDataset`
+            # will later pass it through `active()`/`archived()`)
+            structure(list(
+                self = ds_base_url,
+                index = setNames(list(ds_entity$body), ds_entity$self)
+            ), class = "shoji")
+        }, error = function(...) NULL) # But if we don't find it just return empty catalog
+
+        return(DatasetCatalog(pseudo_shoji))
     }
 
     # Resolve `project`
     if (is.null(project)) {
         project <- projects()
     } else if (!is.project(project)) {
-        ## Project name, URL, or index
-        project <- projects()[[project]]
-    }
-    if (is.null(project)) {
-        ## Means a project was specified (like by name) but it didn't exist
-        halt(
-            "Project ", deparseAndFlatten(eval.parent(Call$project)),
-            " is not valid"
-        )
+        project <- ProjectFolder(crGET(resolveProjectURL(project)))
     }
 
-    # If there is a path in `x`, walk it within `project`
     if (length(dspath) > 1) {
         project <- cd(project, dspath[-length(dspath)])
     }
