@@ -40,7 +40,7 @@ notifyIfNewVersion <- function(package = "crunch",
 #' @importFrom utils compareVersion
 checkForNewVersion <- function(github, installed.version) {
     # Only check if this option isn't set *and* if the session is interactive
-    if (envOrOption("crunch.check.updates", is.interactive())) {
+    if (envOrOption("crunch.check.updates", is.interactive(), expect_lgl = TRUE)) {
         github.url <- paste0("https://api.github.com/repos/", github, "/tags") # nolint
         ## Get the names of the tagged versions on GitHub
         gh.tags <- vapply(crGET(github.url), vget("name"), character(1))
