@@ -42,7 +42,7 @@ test_that("getDimTypes returns the expected cube dimension types", {
 
 with_mock_crunch({
     ## Load a ton of cube fixtures via the tab book feature
-    ds <- loadDataset("test ds")
+    ds <- cachedLoadDataset("test ds")
     m <- multitables(ds)[[1]]
     with_POST("https://app.crunch.io/api/datasets/1/multitables/apidocs-tabbook/", {
         book <- tabBook(m, data = ds)
