@@ -2,7 +2,7 @@ context("Update variables with NAs")
 
 with_mock_crunch({
     ds <- cachedLoadDataset("test ds")
-    ds2 <- loadDataset("an archived dataset", kind = "archived")
+    ds2 <- loadDataset("2", "archived", project = NULL)
 
     test_that("If an array gets NA assigned and it doesn't have No Data, we add that category", {
         expect_PATCH(
